<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Archivo;

class ArchivoController extends Controller
{
    public function index()
    {
        $titlePag= 'ARCHIVOS';
        $archivos = Archivo::all();
        return view('archivos.index')
        ->with('archivos', $archivos)
        ->with('titlePag', $titlePag);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Archivo  $archivo
     * @return \Illuminate\Http\Response
     */
    public function edit(Archivo $archivo){

        $titlePag= 'EDITAR ARCHIVO';

        return view("archivos.editar", compact('titlePag','archivo'));
    }

    public function update(Request $request){

        $titlePag= 'ARCHIVO AÑADIDO';

        

        $validacion= $request->validate([
            'titulo' => 'required',
            'descripcion_corta' => 'required',
            'descripcion',
            'instrucciones',
            'periodicidad' => 'required',
        ]);

        if ($validacion){ 

        $archivo = Archivo::find($request->id);

        $archivo->update($request->all());

        return view('archivos.show')
        ->with('archivo', $archivo)
        ->with('titlePag', $titlePag);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Archivo  $archivo
     * @return \Illuminate\Http\Response
     */
    public function delete($id){

        $archivo = Archivo::find($id);
        
        //////////// 
        $archivo->establecimientos()->detach();
        $archivo->perfiles()->detach();
        $archivo->departamentos()->detach();
        $archivo->delete();
        //////////// Borrar el archivo de la carpeta public\storage\uploads
        $filepath = public_path().$archivo->file_path; //Ruta concreta del archivo
        unlink($filepath); //borra el archivo
        $archivos=Archivo::all();
    
        return back();
    }

    public function create(){

        $titlePag= 'SUBIR ARCHIVO';
        return view('archivos.crear')
        ->with('titlePag', $titlePag);
    }

    public function store(Request $req){

        $titlePag= 'ARCHIVO EDITADO';

        $validacion = $req->validate([
        'file' => 'required|mimes:pdf,doc,docx,xls,xlsx,ppt,pptx',
        'titulo' => 'required',
        'descripcion_corta' => 'required',
        'descripcion',
        'instrucciones',
        'periodicidad' => 'required'
        ]);
      
        if ($validacion) {
            $archivo = new Archivo;
            if($req->file()) {
                $fileName = time().'_'.$req->file->getClientOriginalName();
                $filePath = $req->file('file')->storeAs('uploads', $fileName, 'public');
                $archivo->titulo = time().'_'.$req->file->getClientOriginalName();
                $archivo->file_path = '/storage/' . $filePath;
                $archivo->descripcion_corta = $req->descripcion_corta;
                $archivo->descripcion = $req->descripcion;
                $archivo->instrucciones = $req->instrucciones;
                $archivo->periodicidad = $req->periodicidad;
                $archivo->save();
        }
        
            return view('archivos.show')
            ->with('archivo', $archivo)
            ->with('titlePag', $titlePag);
        }
    }

    public function show($id)
    {
        $titlePag= 'DETALLES ARCHIVO';
        $archivo = Archivo::find($id);
        return view('archivos.show')
        ->with('archivo', $archivo)
        ->with('titlePag', $titlePag);
    }

    public function download(Archivo $archivo){

        $archivo2 = public_path().$archivo->file_path;
        $headers = ['Content-Type: application/pdf'];
        if (file_exists($archivo2)) {
            return response()->download($archivo2, $archivo->name, $headers);
        } else {
            echo('archivo no encontrado');
        }
    }
}
