<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\ProfileUpdateRequest;
use App\Models\User;
use App\Models\Perfil;
use App\Models\Establecimiento;
use App\Models\Departamento;
use App\Providers\RouteServiceProvider;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $perfiles=Perfil::all();
        $establecimientos=Establecimiento::all();
        $departamentos=Departamento::all();

        return view('auth.register',  compact('perfiles','establecimientos','departamentos'));
    }

    /**
     * Handle an incoming registration request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(ProfileUpdateRequest $request)
    {
        
        $validacion = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'lastname' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
        ]);

        if ($validacion) {
            if (isset($_POST['establecimientos']) && isset($_POST['departamentos']) && isset($_POST['perfiles'])) {
                $countestablecimientos = 0;
                $checkedestablecimientos = $_POST['establecimientos'];
                $countestablecimientos = count($checkedestablecimientos);
                //dd($countestablecimientos);

                $countdepartamentos = 0;
                $checkeddepartamentos = $_POST['departamentos'];
                $countdepartamentos = count($checkeddepartamentos);

                $countperfiles = 0;
                $checkedperfiles = $_POST['perfiles'];
                $countperfiles = count($checkedperfiles);

            
                    if ($countestablecimientos>0 && $countperfiles>0 && $countdepartamentos>0) {
                        $user = User::create([
                            'name' => $request->name,
                            'lastname' => $request->lastname,
                            'email' => $request->email,
                            'password' => Hash::make($request->password),
                        ]);
                        //dd($request->establecimientos);
                        $establecimientos = Establecimiento::find($request->establecimientos);
                        $user->establecimientos()->syncWithoutDetaching($establecimientos);
                        $departamentos = Departamento::find($request->departamentos);
                        $user->departamentos()->syncWithoutDetaching($departamentos);
                        $perfiles = Perfil::find($request->perfiles);
                        $user->perfiles()->syncWithoutDetaching($perfiles);
        
                    event(new Registered($user));
        
                    Auth::login($user);
        
                    return redirect('/');

                } else {
                    $perfiles=Perfil::all();
                    $establecimientos=Establecimiento::all();
                    $departamentos=Departamento::all();
                    

                    return view('auth.register',  compact('perfiles','establecimientos','departamentos'))->with('message', 'Por favor marca al menos una casilla de cada apartado');
                }
            }else {
                $perfiles=Perfil::all();
                $establecimientos=Establecimiento::all();
                $departamentos=Departamento::all();
                
                return view('auth.register',  compact('perfiles','establecimientos','departamentos'))->with('message', 'Por favor marca al menos una casilla de cada apartado');
            }
        }
    }
}
