<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'lastname',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function establecimientos() 
    {
        return $this->belongsToMany(Establecimiento::class,'establecimiento_usuarios','usuario_id','establecimiento_id')->withTimestamps();
    }

    public function perfiles() 
    {
        return $this->belongsToMany(Perfil::class,'perfil_usuarios','usuario_id','perfil_id')->withTimestamps();
    }

    public function departamentos() 
    {
        return $this->belongsToMany(Departamento::class,'departamento_usuarios','usuario_id','departamento_id')->withTimestamps();
    }

    public function archivos() 
    {
        return $this->belongsToMany(Archivo::class,'archivo_usuarios','usuario_id','archivo_id')->withTimestamps();
    }

    public static function last()
    {
        return self::latest()->first();
    }
}
