<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ArchivoController;
use App\Http\Controllers\DepartamentoController;
use App\Http\Controllers\PerfilController;
use App\Http\Controllers\EmpresaController;
use App\Http\Controllers\EstablecimientoController;
use App\Http\Controllers\ProfileController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Route::get('/', function () {
    return view('inicio');
})->name('inicio');

Route::group(attributes: ['middleware' => 'auth'], routes: function(){
    Route::view(uri:'profile', view:'profile')->middleware(['auth'])->name(name:'profile');
    Route::put(uri:'profile', action:[ProfileController::class, 'update'])->name(name:'profile.update');

    Route::get('departamentos/create', [DepartamentoController::class, 'create'])->name('departamentos.create');
    Route::post('departamentos/store', [DepartamentoController::class, 'store'])->name('departamentos.store');
    Route::get('departamentos/{departamento}/edit', [DepartamentoController::class, 'edit'])->name('departamentos.edit');
    Route::put('departamentos/{id}', [DepartamentoController::class, 'update'])->name('departamentos.update');
    Route::get('departamentos/{id}', [DepartamentoController::class, 'delete'])->name('departamentos.delete');

    Route::get('archivos/create', [ArchivoController::class, 'create'])->name('archivos.create');
    Route::post('archivos/store', [ArchivoController::class, 'store'])->name('archivos.store');
    Route::get('archivos/{archivo}/edit', [ArchivoController::class, 'edit'])->name('archivos.edit');
    Route::put('archivos/{id}', [ArchivoController::class, 'update'])->name('archivos.update');
    Route::get('archivos/{id}/delete', [ArchivoController::class, 'delete'])->name('archivos.delete');
    Route::get('archivos/{archivo}', [ArchivoController::class, 'download'])->name('archivos.descargar');

    Route::get('empresas/create', [EmpresaController::class, 'create'])->name('empresas.create');
    Route::post('empresas/store', [EmpresaController::class, 'store'])->name('empresas.store');
    Route::get('empresas/{empresa}/edit', [EmpresaController::class, 'edit'])->name('empresas.edit');
    Route::put('empresas/{id}', [EmpresaController::class, 'update'])->name('empresas.update');
    Route::get('empresas/{id}/delete', [EmpresaController::class, 'delete'])->name('empresas.delete');

    Route::get('establecimientos/create', [EstablecimientoController::class, 'create'])->name('establecimientos.create');
    Route::post('establecimientos/store', [EstablecimientoController::class, 'store'])->name('establecimientos.store');
    Route::get('establecimientos/{establecimiento}/edit', [EstablecimientoController::class, 'edit'])->name('establecimientos.edit');
    Route::put('establecimientos/{id}', [EstablecimientoController::class, 'update'])->name('establecimientos.update');
    Route::get('establecimientos/{id}/delete', [EstablecimientoController::class, 'delete'])->name('establecimientos.delete');

    Route::get('perfiles/create', [PerfilController::class, 'create'])->name('perfiles.create');
    Route::post('perfiles/store', [PerfilController::class, 'store'])->name('perfiles.store');
    Route::get('perfiles/{perfil}/edit', [PerfilController::class, 'edit'])->name('perfiles.edit');
    Route::put('perfiles/{id}', [PerfilController::class, 'update'])->name('perfiles.update');
    Route::get('perfiles/{id}/delete', [PerfilController::class, 'delete'])->name('perfiles.delete');
});

Route::get('perfiles/show/{perfil}', [PerfilController::class, 'show'])->name('perfiles.mostrar');
Route::get('establecimientos/show/{establecimiento}', [EstablecimientoController::class, 'show'])->name('establecimientos.mostrar');
Route::get('empresas/show/{empresa}', [EmpresaController::class, 'show'])->name('empresas.mostrar');
Route::get('departamentos/show/{departamento}', [DepartamentoController::class, 'show'])->name('departamentos.mostrar');
Route::get('archivos/show/{archivo}', [ArchivoController::class, 'show'])->name('archivos.mostrar');

Route::resource('archivos', ArchivoController::class)->except(['create', 'store', 'edit', 'update', 'delete', 'show']);
Route::resource('departamentos', DepartamentoController::class)->except(['create', 'store', 'edit', 'update', 'delete', 'show']);
Route::resource('perfiles', PerfilController::class)->except(['create', 'store', 'edit', 'update', 'delete', 'show']);
Route::resource('empresas', EmpresaController::class)->except(['create', 'store', 'edit', 'update', 'delete', 'show', 'destroy']);
Route::resource('establecimientos', EstablecimientoController::class)->except(['create', 'store', 'edit', 'update', 'delete', 'show']);

Route::get('/listadetareas', function () {
    return view('listadetareas');
})->middleware(['auth'])->name('listadetareas');

require __DIR__.'/auth.php';


